@@ -30,6 +30,18 @@ class Requests:
     async def get_road(self, roadeids: list = None, area: BaseGeometry = None) -> dict:
         return await self._get_location(roadeids, area, RequestPath.road)
 
+    async def get_road_center(self, roadeids: list = None, area: BaseGeometry = None) -> dict:
+        return await self._get_location(roadeids, area, SEPARATOR.join((RequestPath.road, RequestPath.roadcenter)))
+
+    async def get_turn_ratio(self, fromroad: str = None, toroad: str = None) -> dict:
+        params = {}
+        if fromroad is not None:
+            params[RequestParam.fromroad] = fromroad
+        if toroad is not None:
+            params[RequestParam.toroad] = toroad
+        return await self._get(SEPARATOR.join((RequestPath.road, RequestPath.roadcenter, RequestPath.turnratio)),
+                               params)
+
     async def get_zone_point(self, zoneeids: list = None, area: BaseGeometry = None) -> dict:
         return await self._get_location(zoneeids, area, RequestPath.zonepoint)
 
@@ -144,19 +156,6 @@ class Requests:
             params[RequestParam.sampling] = sampling
         return await self._get(SEPARATOR.join((RequestPath.zonepoint, RequestPath.traveltime)), params)
 
-
-    async def get_road_center(self, roadeids: list = None, area: BaseGeometry = None) -> dict:
-        return await self._get_location(roadeids, area, SEPARATOR.join((RequestPath.road, RequestPath.roadcenter)))
-
-    async def get_turn_ratio(self, fromroad: str, toroad: str, params = None) -> dict:
-        if params is None:
-            params = {}
-        if fromroad is not None:
-            params[RequestParam.fromroad] = fromroad
-        if toroad is not None:
-            params[RequestParam.toroad] = toroad
-        return await self._get(SEPARATOR.join((RequestPath.road, RequestPath.roadcenter, RequestPath.turnratio)), params)
-
     async def _get(self, suffix: str, params: dict = None) -> dict:
         if params is None:
             params = {}
