@@ -13,6 +13,7 @@ LONLAT_EXTEND = ((5.60268, 45.0821), (5.88934, 45.2674))
 EXTEND_BBOX_XY = None
 SRID = 4326
 R = 6371000  # earth radius in meters
+ONE_METER_IN_LATLON = .0000128
 
 
 def geom_to_xy(geom: BaseGeometry, lonlatcenter: Tuple[float, float] = None, rounding: int = 2) -> BaseGeometry:
@@ -103,6 +104,12 @@ def round_lonlat(lonlat: Tuple[float, float]) -> Tuple[int, int]:
     return round(lonlat[0] * 1000), round(lonlat[1] * 1000)
 
 
+def shift_to_right(geom: shapely.geometry.LineString, dist: int) -> shapely.geometry.LineString:
+    geom = geom.parallel_offset(dist, 'right')
+    geom.coords = list(geom.coords)[::-1]
+    return geom
+
+
 def is_inside_extend(geomxy: BaseGeometry) -> bool:
     global EXTEND_BBOX_XY
     if EXTEND_BBOX_XY is None:
